==> asksuite-core-1.0.21.tgz: package/bellavista.crawler.js <==
const cheerio = require('cheerio');
const HeadlessChrome = require('simple-headless-chrome-asksuite')
require('datejs')
const browser = new HeadlessChrome({
    headless: true // If you turn this off, you can actually see the browser navigate with your instructions
    // see above if using remote interface
})

function replace(str) {
    return str.replace(new RegExp('\t', 'g'), "")
}


function getNumber(str) {
    var regex = /\d+/g;
    var matches = str.match(regex);

    console.log(matches);

    return matches[0];
}

function parse(parseData) {
    var split = parseData.split('-');
    return new Date(split[2], split[1], split[0])
}

async function navigateWebsite(url, checkin, checkout, adultos, criancas, bebes) {
    try {
        await browser.init()

        const mainTab = await browser.newTab({privateTab: false})

        // Navigate to a URL

        //https://cariciadovento.belaviagem.com/motor/from:hotel/idrede:/datain:06-02-2018/dataout:08-02-2018/rfsh:1/pax:2/

        // let strQuartos = `quarto_1=${adultos}**undefined**${criancas}**${bebes}`

        // let urlBuild = `${url}/motor-de-reservas/selecionar-quarto.php?periodo1=${checkin}&periodo2=${checkout}&cidade=&quartos=1&${strQuartos}`

        let urlBuild = `${url}/motor/from:hotel/idrede:/datain:${checkin}/dataout:${checkout}/rfsh:1/pax:${adultos}`
        await mainTab.injectRemoteScript("https://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js")


        console.log(urlBuild);

        await mainTab.goTo(urlBuild, {timeout: 20000})
        // await mainTab.wait(1000000);


        // await mainTab.waitForPageToLoad(20000)
        await mainTab.waitForSelectorToLoad('body')


        const htmlTag = await mainTab.evaluate(function (selector) {
            const selectorHtml = document.querySelector(selector)
            return selectorHtml.innerHTML
        }, 'body'); // returns innerHTML of first matching selector for class "main"


        let $ = cheerio.load(htmlTag.result.value);
        let promise = null;

        let rooms = [];

        $(".apto").each((index, item) => {

            let room = new HotelRoom();

            let tdx = $(item);

            room.description = replace(tdx.find('.desc_ac').text())

            let nomePreco = tdx.find('.nome_preco');
            room.name = replace(tdx.find('h3').text().replace('Último disponível', ''));
            room.price = replace(nomePreco.find('.valor').text());

            if (room.price) {

                var date1 = parse(checkin)
                var date2 = parse(checkout)

                var diffDays = parseInt((date2 - date1) / (1000 * 60 * 60 * 24));
                let tempPrice = parseFloat(room.price.replace("R$", ''))

                room.total = "R$ " + ((tempPrice * diffDays).toFixed(2)).replace(".", ",");


                tdx.find('.unveil').each((index, itemAmenite) => {
                    room.images.push(url + $(itemAmenite).attr('data-src'));
                });


                tdx.find('.serv.info_lista').each((index, itemAmenite) => {
                    room.amenites.push($(itemAmenite).attr('data-content'));
                });


                room.amountAdults = getNumber(replace(tdx.find('.acomoda').text()))

                if (room.images) {
                    room.mainPhoto = room.images[0];
                }
                rooms.push(room)
            }


        })


        if (rooms && rooms.length > 0) {

            let obj = {
                data: rooms,
                url: urlBuild,
            };

            promise = Promise.resolve(obj)
        } else {
            let obj = {
                message: replace($('#tab_reserveonline > div > div').text())
            };

            promise = await Promise.reject(obj)
        }


        await browser.close()


        return promise;

    } catch (err) {
        console.log(err)
        browser.close()
        throw err;
    }
}
//
// // //
// navigateWebsite('https://cariciadovento.belaviagem.com', '06-02-2018', '06-02-2018', 2, 1).then(data => {
//     console.log("sucesso")
// }).catch(error => {
//     console.log("caiu aqui")
//     console.log(error.message);
// })

class HotelRoom {

    constructor() {
        this.amenites = new Array();
        this.images = new Array();
    }

}


module.exports = {search: navigateWebsite}

==> asksuite-core-1.0.51.tgz: package/bellavista.crawler.js <==
const cheerio = require('cheerio');
const HeadlessChrome = require('simple-headless-chrome-asksuite');
require('datejs');


let options = {
    flags: [
        '-blink-settings=imagesEnabled=false'
    ]
};

const browser = new HeadlessChrome({
    headless: true, // If you turn this off, you can actually see the browser navigate with your instructions
    chrome: options
    // see above if using remote interface
});

function replace(str) {
    return str.replace(new RegExp('\t', 'g'), "")
}


function getNumber(str) {
    let regex = /\d+/g;
    let matches = str.match(regex);

    console.log(matches);

    return matches[0];
}

function parse(parseData) {
    let split = parseData.split('-');
    return new Date(split[2], split[1], split[0])
}

async function navigateWebsite(url, checkin, checkout, adultos, criancas, bebes) {
    try {
        await browser.init()

        const mainTab = await browser.newTab({privateTab: false})

        // Navigate to a URL

        //https://cariciadovento.belaviagem.com/motor/from:hotel/idrede:/datain:06-02-2018/dataout:08-02-2018/rfsh:1/pax:2/

        // let strQuartos = `quarto_1=${adultos}**undefined**${criancas}**${bebes}`

        // let urlBuild = `${url}/motor-de-reservas/selecionar-quarto.php?periodo1=${checkin}&periodo2=${checkout}&cidade=&quartos=1&${strQuartos}`

        let urlBuild = `${url}/motor/from:hotel/idrede:/datain:${checkin}/dataout:${checkout}/rfsh:1/pax:${adultos}`
        await mainTab.injectRemoteScript("https://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js")


        console.log(urlBuild);

        await mainTab.goTo(urlBuild, {timeout: 20000})
        // await mainTab.wait(1000000);


        // await mainTab.waitForPageToLoad(20000)
        await mainTab.waitForSelectorToLoad('body')


        const htmlTag = await mainTab.evaluate(function (selector) {
            const selectorHtml = document.querySelector(selector)
            return selectorHtml.innerHTML
        }, 'body'); // returns innerHTML of first matching selector for class "main"


        let $ = cheerio.load(htmlTag.result.value);
        let promise = null;

        let rooms = [];

        $(".apto").each((index, item) => {

            let room = new HotelRoom();

            let tdx = $(item);

            room.description = replace(tdx.find('.desc_ac').text())

            let nomePreco = tdx.find('.nome_preco');
            room.name = replace(tdx.find('h3').text().replace('Último disponível', ''));
            room.price = replace(nomePreco.find('.valor').text());

            if (room.price) {

                let date1 = parse(checkin)
                let date2 = parse(checkout)

                let diffDays = parseInt((date2 - date1) / (1000 * 60 * 60 * 24));
                let tempPrice = parseFloat(room.price.replace("R$", ''))

                room.total = "R$ " + ((tempPrice * diffDays).toFixed(2)).replace(".", ",");


                tdx.find('.unveil').each((index, itemAmenite) => {
                    room.images.push(url + $(itemAmenite).attr('data-src'));
                });


                tdx.find('.serv.info_lista').each((index, itemAmenite) => {
                    room.amenites.push($(itemAmenite).attr('data-content'));
                });


                room.amountAdults = getNumber(replace(tdx.find('.acomoda').text()))

                if (room.images) {
                    room.mainPhoto = room.images[0];
                }
                rooms.push(room)
            }


        })


        if (rooms && rooms.length > 0) {

            let obj = {
                data: rooms,
                url: urlBuild,
            };

            promise = Promise.resolve(obj)
        } else {
            let obj = {
                message: replace($('#tab_reserveonline > div > div').text())
            };

            promise = await Promise.reject(obj)
        }


        await browser.close()


        return promise;

    } catch (err) {
        console.log(err)
        browser.close()
        throw err;
    }
}
//
// // //
// navigateWebsite('https://cariciadovento.belaviagem.com', '22-03-2018', '24-03-2018', 2, 1).then(data => {
//     console.log("sucesso")
// }).catch(error => {
//     console.log("caiu aqui")
//     console.log(error.message);
// })

class HotelRoom {

    constructor() {
        this.amenites = new Array();
        this.images = new Array();
    }

}


module.exports = {search: navigateWebsite}
